==> snowflake-jdbc-3.0.0-sources.jar: net/snowflake/client/loader/LoaderProperty.java <==
/*
 * Copyright (c) 2012-2016 Snowflake Computing Inc. All right reserved.
 */

package net.snowflake.client.loader;


/**
 * Configuration parameters for Loader
 */
public enum LoaderProperty
{
     tableName,         // Target table name                                          String
     schemaName,        // Target table schema                                        String
     databaseName,      // Target table database                                      String
     remoteStage,       // Stage to use - "~" is default                              String
     columns,           // List of columns that will be uploaded                      List<String>
     keys,              // List of columns used as keys for updating                  List<String>
     operation,         // UPDATE, DELETE, MODIFY, UPSERT                             Enum Operation
     asyncData,         // buffer accepted data row in a queue                        Boolean
     startTransaction,  // start transaction for the operation                        Boolean
     oneBatch,          // process all data in one batch                              Boolean
     truncateTable,     // delete all data from the table prior to run                Boolean
     executeBefore,     // SQL statement to execute before run                        String
     executeAfter,      // SQL statement to execute after run                         String
     isFirstStartCall,  // skip deleting data. Used in multiple calls of loader.start Boolean
     isLastFinishCall,  // skip commit. Used in multiple calls of loader.finish       Boolean
     batchRowSize,      // Batch row size. Flush queues when it reaches this          Long
     csvFileBucketSize, // File bucket size                                           Long
     csvFileSize,       // File size                                                  Long
}

==> snowflake-jdbc-3.0.4-sources.jar: net/snowflake/client/loader/LoaderProperty.java <==
/*
 * Copyright (c) 2012-2016 Snowflake Computing Inc. All right reserved.
 */

package net.snowflake.client.loader;


/**
 * Configuration parameters for Loader
 */
public enum LoaderProperty
{
     tableName,         // Target table name                                          String
     schemaName,        // Target table schema                                        String
     databaseName,      // Target table database                                      String
     remoteStage,       // Stage to use - "~" is default                              String
     columns,           // List of columns that will be uploaded                      List<String>
     keys,              // List of columns used as keys for updating                  List<String>
     operation,         // UPDATE, DELETE, MODIFY, UPSERT                             Enum Operation
     startTransaction,  // start transaction for the operation                        Boolean
     oneBatch,          // process all data in one batch                              Boolean
     truncateTable,     // delete all data from the table prior to run                Boolean
     executeBefore,     // SQL statement to execute before run                        String
     executeAfter,      // SQL statement to execute after run                         String
     isFirstStartCall,  // skip deleting data. Used in multiple calls of loader.start Boolean
     isLastFinishCall,  // skip commit. Used in multiple calls of loader.finish       Boolean
     batchRowSize,      // Batch row size. Flush queues when it reaches this          Long
     csvFileBucketSize, // File bucket size                                           Long
     csvFileSize,       // File size                                                  Long
     preserveStageFile, // Preserve stage files if error occurs                       Boolean
     useLocalTimezone,  // Use local timezone in converting TIMESTAMP                 Boolean
     // test parameters
     testRemoteBadCSV   // TEST: Inject bad CSV in the remote stage                   Boolean
}
